#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 idris
version:              1.3.3
visibility:           public
id:                   idris-1.3.3-C6dvDBpj01lBo3v2rD3dNJ
key:                  idris-1.3.3-C6dvDBpj01lBo3v2rD3dNJ
license:              BSD-3-Clause
maintainer:           Niklas Larsson <niklas@mm.st>
author:               Edwin Brady
stability:            Beta
homepage:             https://www.idris-lang.org/
synopsis:             Functional Programming Language with Dependent Types
description:
    Idris is a general purpose language with full dependent types.
    It is compiled, with eager evaluation.
    Dependent types allow types to be predicated on values,
    meaning that some aspects of a program'\''s behaviour can be
    specified precisely in the type. The language is closely
    related to Epigram and Agda. There is a tutorial at
    <https://www.idris-lang.org/documentation>.
    Features include:

    * Full, first class, dependent types with dependent pattern matching

    * where clauses, with rule, case expressions,
    pattern matching let and lambda bindings

    * Interfaces (similar to type classes), monad comprehensions

    * do notation, idiom brackets, syntactic conveniences for lists,
    tuples, dependent pairs

    * Totality checking

    * Coinductive types

    * Indentation significant syntax, extensible syntax

    * Cumulative universes

    * Simple foreign function interface (to C)

    * Hugs style interactive environment

category:             Compilers/Interpreters, Dependent Types
abi:                  436d4d086ef98926ff4fa251dcd1d3e6
exposed:              True
exposed-modules:
    IRTS.Bytecode IRTS.CodegenC IRTS.CodegenCommon
    IRTS.CodegenJavaScript IRTS.Compiler IRTS.Defunctionalise
    IRTS.DumpBC IRTS.Exports IRTS.Inliner IRTS.JavaScript.AST
    IRTS.JavaScript.Codegen IRTS.JavaScript.LangTransforms
    IRTS.JavaScript.Name IRTS.JavaScript.PrimOp
    IRTS.JavaScript.Specialize IRTS.Lang IRTS.LangOpts IRTS.Portable
    IRTS.Simplified IRTS.System Idris.ASTUtils Idris.AbsSyntax
    Idris.AbsSyntaxTree Idris.Apropos Idris.CaseSplit Idris.Chaser
    Idris.CmdOptions Idris.Colours Idris.Completion Idris.Core.Binary
    Idris.Core.CaseTree Idris.Core.Constraints Idris.Core.DeepSeq
    Idris.Core.Elaborate Idris.Core.Evaluate Idris.Core.Execute
    Idris.Core.ProofState Idris.Core.ProofTerm Idris.Core.TT
    Idris.Core.Typecheck Idris.Core.Unify Idris.Core.WHNF
    Idris.Coverage Idris.DSL Idris.DataOpts Idris.DeepSeq
    Idris.Delaborate Idris.Directives Idris.Docs Idris.Docstrings
    Idris.Elab.AsPat Idris.Elab.Clause Idris.Elab.Data
    Idris.Elab.Implementation Idris.Elab.Interface Idris.Elab.Provider
    Idris.Elab.Quasiquote Idris.Elab.Record Idris.Elab.Rewrite
    Idris.Elab.RunElab Idris.Elab.Term Idris.Elab.Transform
    Idris.Elab.Type Idris.Elab.Utils Idris.Elab.Value Idris.ElabDecls
    Idris.Erasure Idris.ErrReverse Idris.Error Idris.Help Idris.IBC
    Idris.IdeMode Idris.IdrisDoc Idris.Imports Idris.Info
    Idris.Info.Show Idris.Inliner Idris.Interactive Idris.Main
    Idris.ModeCommon Idris.Options Idris.Output Idris.Package
    Idris.Package.Common Idris.Package.Parser Idris.Parser
    Idris.Parser.Data Idris.Parser.Expr Idris.Parser.Helpers
    Idris.Parser.Ops Idris.Parser.Stack Idris.PartialEval
    Idris.Primitives Idris.ProofSearch Idris.Prover Idris.Providers
    Idris.REPL Idris.REPL.Browse Idris.REPL.Commands Idris.REPL.Parser
    Idris.Reflection Idris.Termination Idris.Transforms
    Idris.TypeSearch Idris.Unlit Idris.WhoCalls Util.DynamicLinker
    Util.ScreenSize Util.System

hidden-modules:
    Util.Pretty Util.Net Paths_idris Version_idris Tools_idris
    BuildFlags_idris

import-dirs:          /usr/lib/ghc-8.10.4/site-local/idris-1.3.3
library-dirs:         /usr/lib/ghc-8.10.4/site-local/idris-1.3.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/idris
hs-libraries:         HSidris-1.3.3-C6dvDBpj01lBo3v2rD3dNJ
extra-libraries:      gmp
depends:
    aeson-1.5.6.0-5eoOZXqtB1gFFr96oMLNs3
    annotated-wl-pprint-0.7.0-HXu68S9Nys8Hg2W61VXV5e
    ansi-terminal-0.11-ChZQ4tet9RpCZKLIWEgagm
    ansi-wl-pprint-0.6.9-68bFt3W09M41WZGM9eWA92 array-0.5.4.0
    async-2.2.3-bRJqoep3gj749cy8sss28 base-4.14.1.0
    base64-bytestring-1.2.0.1-2sizeXr5YuKHleVBnJwnDa binary-0.8.8.0
    blaze-html-0.9.1.2-4FwX4FE2DyM4IyjPq9GUHB
    blaze-markup-0.8.2.8-AcEDCa2jFpd7MBv420o2ga bytestring-0.10.12.0
    cheapskate-0.1.1.2-5iqFn1jmZAuE1aETyuiRbz
    code-page-0.2.1-IAY0xrIpRX4LqP27RFJNQj containers-0.6.2.1
    deepseq-1.4.4.0 directory-1.3.6.0 filepath-1.4.2.1
    fingertree-0.1.4.2-AmH3Vj9socPHSRG2yL4rUg
    fsnotify-0.3.0.1-BwkFwcsBOyr70vmhXdmMnA haskeline-0.8.0.1
    ieee754-0.8.0-Fa1NJsiKKLb2eXdrTUzFMJ
    libffi-0.1-9IaAnagAd9mHZyIx4Vvu1D
    megaparsec-9.0.1-ApG4XKn00rg31mIJ9ZXWqt mtl-2.2.2
    network-3.1.2.1-IbGp7WYUsXwHVhR4UsCZRD
    optparse-applicative-0.16.1.0-Aums8NSUQ7MCCMQ1RSMBhb
    parser-combinators-1.3.0-DiU4leLN1bk4yjPVc8BdOd pretty-1.1.3.6
    process-1.6.9.0 regex-tdfa-1.3.1.0-JGQEzvFVQF39kClVWuccwj
    safe-0.3.19-AfrHSVViU1189qUhjBUb5b
    split-0.2.3.4-IvR0X8Ou77iJ5fuZypuAy5
    terminal-size-0.3.2.1-HihNy0RThZk4O1UkYpAxTd text-1.2.4.1
    time-1.9.3 transformers-0.5.6.2
    uniplate-1.6.13-qb1C6SDn3Y3yqIWiLfO6w unix-2.7.2.2
    unordered-containers-0.2.13.0-L0eBZW05rpSJOXS7yU5DxX
    utf8-string-1.0.2-7pqBkplor7g1hjwTjVt3SV
    vector-0.12.3.0-DZd2wim9OGg7KbOKVPP1I9
    vector-binary-instances-0.2.5.2-3HRIkzUQqWK5CIvmqhLjo2
    zip-archive-0.4.1-6gJJt9LonDt7ShBaRx6N4d

haddock-interfaces:   /usr/share/doc/idris/html/idris.haddock
haddock-html:         /usr/share/doc/idris/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

